@@ -138,10 +138,10 @@ class GeneticCodes:
             key = self.name2id[key]
         return self.codes[key]
 
-    def get_code(self, id):
+    def get_code(self, id) -> GeneticCode:
         return self[id]
     
-    def translate(self, seq, id):
+    def translate(self, seq, id=1):
         return self[id].translate(seq)
     
     def get_valid_names(self):
