@@ -3,7 +3,7 @@ import argparse
 
 from typing import Iterable, Iterator
 from lhc.binf.genomic_coordinate import GenomicInterval
-from lhc.io.loci import open_loci_file
+from lhc.io.locus import open_locus_file
 
 
 def view(intervals: Iterable[GenomicInterval]) -> Iterator[GenomicInterval]:
@@ -33,8 +33,8 @@ def define_parser(parser):
 
 
 def init_view(args):
-    with open_loci_file(args.input, format=args.input_format) as input,\
-            open_loci_file(args.output, 'w', format=args.output_format) as output:
+    with open_locus_file(args.input, format=args.input_format) as input,\
+            open_locus_file(args.output, 'w', format=args.output_format) as output:
         for interval in view(input):
             output.write(interval)
 
