@@ -1,6 +1,6 @@
 import argparse
 
-from .tools import extract, filter, get, split, stat
+from .tools import extract, filter, split, stat_, unique
 
 
 def main():
@@ -18,9 +18,9 @@ def define_parser(parser):
     for name, define_parser_ in (
             ('extract', extract.define_parser),
             ('filter', filter.define_parser),
-            ('get',  get.define_parser),
             ('split', split.define_parser),
-            ('stat', stat.define_parser)):
+            ('stat', stat_.define_parser),
+            ('unique', unique.define_parser)):
         subparser = subparsers.add_parser(name)
         define_parser_(subparser)
     return parser
