@@ -1,13 +1,14 @@
 from collections import OrderedDict, namedtuple
+from typing import Iterator
+from lhc.binf.genomic_coordinate import GenomicPosition
 
 Variant = namedtuple('Variant', ('pos', 'id', 'ref', 'alt', 'qual', 'filter', 'info', 'format', 'samples'))
 
 
 class VcfIterator:
-
     __slots__ = ('iterator', 'header', 'samples')
 
-    def __init__(self, iterator):
+    def __init__(self, iterator: Iterator[str]):
         self.iterator = iterator
         self.header, self.samples = get_header(iterator)
 
@@ -18,17 +19,16 @@ class VcfIterator:
         parts = next(self.iterator).rstrip('\r\n').split('\t')
         info = dict(i.split('=', 1) if '=' in i else (i, i) for i in parts[7].split(';'))
         format = None if len(parts) < 9 else parts[8].split(':')
-        return Variant(
-            (parts[0], int(parts[1]) - 1),
-            parts[2],
-            parts[3],
-            parts[4].split(','),
-            get_float(parts[5]),
-            set(parts[6].split(',')),
-            info,
-            format,
-            get_samples(self.samples, parts[9:], format)
-        )
+        return GenomicPosition(int(parts[1]) - 1, chromosome=parts[0], data={
+            'id': parts[2],
+            'ref': parts[3],
+            'alt': parts[4].split(','),
+            'qual': get_float(parts[5]),
+            'filter': set(parts[6].split(',')),
+            'info': info,
+            'format': format,
+            'samples': get_samples(self.samples, parts[9:], format)
+        })
 
     def __getstate__(self):
         return self.iterator, self.header, self.samples
